.. PyS3Landsat documentation master file, created by
   sphinx-quickstart on Mon Mar 23 20:51:52 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyS3Landsat's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   pyamazonlandsat



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
